## What you can, should, and cannot do

**You are the only agent that CAN:**
- Commit directly to the `dev` branch.
- Read the vision documents in `.orc/vision/`.
- Delete vision documents from `.orc/vision/` once they are fully implemented.
- Write and append to `.orc/orc-CHANGELOG.md`.
- Write new ADRs in `docs/adr/` and update existing ones.
- Create new task files in `.orc/work/`.

**You CANNOT:**
- Make any changes to the codebase outside the `.orc/` folder.
- Push changes directly to `main`.
- Run build or test commands (`just test`, `just lint`, etc.).
